==> zio-aws-redshift_2.13-5.17.104.10-sources.jar: zio/aws/redshift/model/ClusterSnapshotCopyStatus.scala <==
package zio.aws.redshift.model
import zio.aws.redshift.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClusterSnapshotCopyStatus(
    destinationRegion: Option[String] = None,
    retentionPeriod: Option[Long] = None,
    manualSnapshotRetentionPeriod: Option[Integer] = None,
    snapshotCopyGrantName: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus = {
    import ClusterSnapshotCopyStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus
      .builder()
      .optionallyWith(destinationRegion.map(value => value: java.lang.String))(
        _.destinationRegion
      )
      .optionallyWith(retentionPeriod.map(value => value: java.lang.Long))(
        _.retentionPeriod
      )
      .optionallyWith(
        manualSnapshotRetentionPeriod.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.manualSnapshotRetentionPeriod)
      .optionallyWith(
        snapshotCopyGrantName.map(value => value: java.lang.String)
      )(_.snapshotCopyGrantName)
      .build()
  }
  def asReadOnly: zio.aws.redshift.model.ClusterSnapshotCopyStatus.ReadOnly =
    zio.aws.redshift.model.ClusterSnapshotCopyStatus.wrap(buildAwsValue())
}
object ClusterSnapshotCopyStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ClusterSnapshotCopyStatus =
      zio.aws.redshift.model.ClusterSnapshotCopyStatus(
        destinationRegion.map(value => value),
        retentionPeriod.map(value => value),
        manualSnapshotRetentionPeriod.map(value => value),
        snapshotCopyGrantName.map(value => value)
      )
    def destinationRegion: Option[String]
    def retentionPeriod: Option[Long]
    def manualSnapshotRetentionPeriod: Option[Integer]
    def snapshotCopyGrantName: Option[String]
    def getDestinationRegion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("destinationRegion", destinationRegion)
    def getRetentionPeriod: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("retentionPeriod", retentionPeriod)
    def getManualSnapshotRetentionPeriod: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField(
        "manualSnapshotRetentionPeriod",
        manualSnapshotRetentionPeriod
      )
    def getSnapshotCopyGrantName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("snapshotCopyGrantName", snapshotCopyGrantName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus
  ) extends zio.aws.redshift.model.ClusterSnapshotCopyStatus.ReadOnly {
    override val destinationRegion: Option[String] =
      scala.Option(impl.destinationRegion()).map(value => value: String)
    override val retentionPeriod: Option[Long] =
      scala.Option(impl.retentionPeriod()).map(value => value: Long)
    override val manualSnapshotRetentionPeriod: Option[Integer] = scala
      .Option(impl.manualSnapshotRetentionPeriod())
      .map(value => zio.aws.redshift.model.primitives.Integer(value))
    override val snapshotCopyGrantName: Option[String] =
      scala.Option(impl.snapshotCopyGrantName()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus
  ): zio.aws.redshift.model.ClusterSnapshotCopyStatus.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-redshift_2.13-5.17.155.1-sources.jar: zio/aws/redshift/model/ClusterSnapshotCopyStatus.scala <==
package zio.aws.redshift.model
import zio.aws.redshift.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClusterSnapshotCopyStatus(
    destinationRegion: Option[String] = None,
    retentionPeriod: Option[Long] = None,
    manualSnapshotRetentionPeriod: Option[Integer] = None,
    snapshotCopyGrantName: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus = {
    import ClusterSnapshotCopyStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus
      .builder()
      .optionallyWith(destinationRegion.map(value => value: java.lang.String))(
        _.destinationRegion
      )
      .optionallyWith(retentionPeriod.map(value => value: java.lang.Long))(
        _.retentionPeriod
      )
      .optionallyWith(
        manualSnapshotRetentionPeriod.map(value => value: java.lang.Integer)
      )(_.manualSnapshotRetentionPeriod)
      .optionallyWith(
        snapshotCopyGrantName.map(value => value: java.lang.String)
      )(_.snapshotCopyGrantName)
      .build()
  }
  def asReadOnly: zio.aws.redshift.model.ClusterSnapshotCopyStatus.ReadOnly =
    zio.aws.redshift.model.ClusterSnapshotCopyStatus.wrap(buildAwsValue())
}
object ClusterSnapshotCopyStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ClusterSnapshotCopyStatus =
      zio.aws.redshift.model.ClusterSnapshotCopyStatus(
        destinationRegion.map(value => value),
        retentionPeriod.map(value => value),
        manualSnapshotRetentionPeriod.map(value => value),
        snapshotCopyGrantName.map(value => value)
      )
    def destinationRegion: Option[String]
    def retentionPeriod: Option[Long]
    def manualSnapshotRetentionPeriod: Option[Integer]
    def snapshotCopyGrantName: Option[String]
    def getDestinationRegion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("destinationRegion", destinationRegion)
    def getRetentionPeriod: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("retentionPeriod", retentionPeriod)
    def getManualSnapshotRetentionPeriod: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField(
        "manualSnapshotRetentionPeriod",
        manualSnapshotRetentionPeriod
      )
    def getSnapshotCopyGrantName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("snapshotCopyGrantName", snapshotCopyGrantName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus
  ) extends zio.aws.redshift.model.ClusterSnapshotCopyStatus.ReadOnly {
    override val destinationRegion: Option[String] =
      scala.Option(impl.destinationRegion()).map(value => value: String)
    override val retentionPeriod: Option[Long] =
      scala.Option(impl.retentionPeriod()).map(value => value: Long)
    override val manualSnapshotRetentionPeriod: Option[Integer] = scala
      .Option(impl.manualSnapshotRetentionPeriod())
      .map(value => value: Integer)
    override val snapshotCopyGrantName: Option[String] =
      scala.Option(impl.snapshotCopyGrantName()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ClusterSnapshotCopyStatus
  ): zio.aws.redshift.model.ClusterSnapshotCopyStatus.ReadOnly = new Wrapper(
    impl
  )
}
